@@ -47,7 +47,7 @@ describe 'neutron::plugins::ml2::cisco::nexus' do
     {}
   end
 
-  let :default_facts do
+  let :test_facts do
     { :operatingsystem         => 'default',
       :operatingsystemrelease  => 'default',
       :concat_basedir          => '/',
@@ -89,10 +89,10 @@ describe 'neutron::plugins::ml2::cisco::nexus' do
   begin
     context 'on RedHat platforms' do
       let :facts do
-        default_facts.merge({
-          :osfamily               => 'RedHat',
-          :operatingsystemrelease => '7'
-        })
+        @default_facts.merge(test_facts.merge({
+           :osfamily               => 'RedHat',
+           :operatingsystemrelease => '7'
+        }))
       end
 
       let :platform_params do
