@@ -7,18 +7,19 @@ describe 'neutron::server' do
   end
 
   let :params do
-    { :auth_password => 'passw0rd',
-      :auth_user     => 'neutron' }
+    { :password           => 'passw0rd',
+      :username           => 'neutron',
+      :keystone_auth_type => 'password',
+      :project_domain_id  => 'Default',
+      :project_name       => 'services',
+      :user_domain_id     => 'Default',
+      :tenant_name        => 'services' }
   end
 
   let :default_params do
     { :package_ensure                   => 'present',
       :enabled                          => true,
       :auth_type                        => 'keystone',
-      :auth_host                        => 'localhost',
-      :auth_port                        => '35357',
-      :auth_tenant                      => 'services',
-      :auth_user                        => 'neutron',
       :database_connection              => 'sqlite:////var/lib/neutron/ovs.sqlite',
       :database_max_retries             => 10,
       :database_idle_timeout            => 3600,
@@ -27,18 +28,14 @@ describe 'neutron::server' do
       :database_max_pool_size           => 10,
       :database_max_overflow            => 20,
       :sync_db                          => false,
-      :agent_down_time                  => 75,
       :router_scheduler_driver          => 'neutron.scheduler.l3_agent_scheduler.ChanceScheduler',
-      :router_distributed               => false,
       :l3_ha                            => false,
       :max_l3_agents_per_router         => 3,
       :min_l3_agents_per_router         => 2,
-      :l3_ha_net_cidr                   => '169.254.192.0/18',
-      :allow_automatic_l3agent_failover => false
     }
   end
 
-  let :default_facts do
+  let :test_facts do
     { :operatingsystem           => 'default',
       :operatingsystemrelease    => 'default'
     }
@@ -54,14 +51,20 @@ describe 'neutron::server' do
     it { is_expected.to contain_class('neutron::policy') }
 
     it 'configures authentication middleware' do
-      is_expected.to contain_neutron_api_config('filter:authtoken/auth_host').with_value(p[:auth_host]);
-      is_expected.to contain_neutron_api_config('filter:authtoken/auth_port').with_value(p[:auth_port]);
-      is_expected.to contain_neutron_api_config('filter:authtoken/admin_tenant_name').with_value(p[:auth_tenant]);
-      is_expected.to contain_neutron_api_config('filter:authtoken/admin_user').with_value(p[:auth_user]);
-      is_expected.to contain_neutron_api_config('filter:authtoken/admin_password').with_value(p[:auth_password]);
-      is_expected.to contain_neutron_api_config('filter:authtoken/admin_password').with_secret( true )
-      is_expected.to contain_neutron_api_config('filter:authtoken/auth_admin_prefix').with(:ensure => 'absent')
-      is_expected.to contain_neutron_api_config('filter:authtoken/auth_uri').with_value("http://localhost:5000/");
+      is_expected.to contain_neutron_config('keystone_authtoken/auth_type').with_value(p[:keystone_auth_type]);
+      is_expected.to contain_neutron_config('keystone_authtoken/tenant_name').with_value(p[:tenant_name]);
+      is_expected.to contain_neutron_config('keystone_authtoken/username').with_value(p[:username]);
+      is_expected.to contain_neutron_config('keystone_authtoken/password').with_value(p[:password]);
+      is_expected.to contain_neutron_config('keystone_authtoken/password').with_secret( true )
+      is_expected.to contain_neutron_config('keystone_authtoken/auth_uri').with_value("http://localhost:5000/");
+      is_expected.to contain_neutron_config('keystone_authtoken/auth_url').with_value("http://localhost:35357/");
+      is_expected.to contain_neutron_config('keystone_authtoken/project_domain_id').with_value(p[:project_domain_id]);
+      is_expected.to contain_neutron_config('keystone_authtoken/project_name').with_value(p[:project_name]);
+      is_expected.to contain_neutron_config('keystone_authtoken/user_domain_id').with_value(p[:user_domain_id]);
+      is_expected.to contain_neutron_config('keystone_authtoken/admin_tenant_name').with_ensure('absent');
+      is_expected.to contain_neutron_config('keystone_authtoken/admin_user').with_ensure('absent');
+      is_expected.to contain_neutron_config('keystone_authtoken/admin_password').with_ensure('absent');
+      is_expected.to contain_neutron_config('keystone_authtoken/identity_uri').with_ensure('absent');
     end
 
     it 'installs neutron server package' do
@@ -88,14 +91,12 @@ describe 'neutron::server' do
         :tag     => ['neutron-service', 'neutron-db-sync-service'],
       )
       is_expected.not_to contain_class('neutron::db::sync')
-      is_expected.to contain_neutron_api_config('filter:authtoken/auth_admin_prefix').with(
-        :ensure => 'absent'
-      )
       is_expected.to contain_service('neutron-server').with_name('neutron-server')
       is_expected.to contain_neutron_config('DEFAULT/api_workers').with_value(facts[:processorcount])
       is_expected.to contain_neutron_config('DEFAULT/rpc_workers').with_value(facts[:processorcount])
-      is_expected.to contain_neutron_config('DEFAULT/agent_down_time').with_value(p[:agent_down_time])
+      is_expected.to contain_neutron_config('DEFAULT/agent_down_time').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/router_scheduler_driver').with_value(p[:router_scheduler_driver])
+      is_expected.to contain_neutron_config('qos/notification_drivers').with_value('<SERVICE DEFAULT>')
     end
 
     context 'with manage_service as false' do
@@ -124,7 +125,7 @@ describe 'neutron::server' do
         is_expected.to contain_neutron_config('DEFAULT/l3_ha').with_value(true)
         is_expected.to contain_neutron_config('DEFAULT/max_l3_agents_per_router').with_value(3)
         is_expected.to contain_neutron_config('DEFAULT/min_l3_agents_per_router').with_value(2)
-        is_expected.to contain_neutron_config('DEFAULT/l3_ha_net_cidr').with_value('169.254.192.0/18')
+        is_expected.to contain_neutron_config('DEFAULT/l3_ha_net_cidr').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -173,52 +174,95 @@ describe 'neutron::server' do
       end
       it 'should override state_path and lock_path from base class' do
         is_expected.to contain_neutron_config('DEFAULT/state_path').with_value(p[:state_path])
-        is_expected.to contain_neutron_config('DEFAULT/lock_path').with_value(p[:lock_path])
+        is_expected.to contain_neutron_config('oslo_concurrency/lock_path').with_value(p[:lock_path])
       end
     end
 
     context 'with allow_automatic_l3agent_failover in neutron.conf' do
       it 'should configure allow_automatic_l3agent_failover' do
-        is_expected.to contain_neutron_config('DEFAULT/allow_automatic_l3agent_failover').with_value(p[:allow_automatic_l3agent_failover])
+        is_expected.to contain_neutron_config('DEFAULT/allow_automatic_l3agent_failover').with_value('<SERVICE DEFAULT>')
       end
     end
-  end
 
-  shared_examples_for 'a neutron server with auth_admin_prefix set' do
-    [ '/keystone', '/keystone/admin' ].each do |auth_admin_prefix|
-      describe "with keystone_auth_admin_prefix containing incorrect value #{auth_admin_prefix}" do
-        before do
-          params.merge!({
-            :auth_admin_prefix => auth_admin_prefix,
-          })
-        end
-        it do
-          is_expected.to contain_neutron_api_config('filter:authtoken/auth_admin_prefix').with(
-            :value => params[:auth_admin_prefix]
-          )
-        end
+    context 'with qos_notification_drivers parameter' do
+      before :each do
+        params.merge!(:qos_notification_drivers => 'message_queue')
+      end
+      it 'should configure qos_notification_drivers' do
+        is_expected.to contain_neutron_config('qos/notification_drivers').with_value('message_queue')
       end
     end
-  end
 
-  shared_examples_for 'a neutron server with some incorrect auth_admin_prefix set' do
-    [ '/keystone/', 'keystone/', 'keystone' ].each do |auth_admin_prefix|
-      describe "with keystone_auth_admin_prefix containing incorrect value #{auth_admin_prefix}" do
-        before do
-          params.merge!({
-            :auth_admin_prefix => auth_admin_prefix,
-          })
-        end
-        it_raises 'a Puppet::Error', /validate_re\(\): "#{auth_admin_prefix}" does not match/
+    context 'with deprecated auth_plugin parameter' do
+      before :each do
+        params.merge!(:auth_plugin => 'v2password')
+      end
+      it 'should configure auth_plugin' do
+        is_expected.to contain_neutron_config('keystone_authtoken/auth_plugin').with_value('v2password')
+        is_expected.not_to contain_neutron_config('keystone_authtoken/auth_type')
       end
     end
   end
 
   shared_examples_for 'a neutron server with broken authentication' do
     before do
-      params.delete(:auth_password)
+      params.delete(:password)
+    end
+    it_raises 'a Puppet::Error', /Either auth_password or password must be set when using keystone authentication/
+  end
+
+  shared_examples_for 'a neutron server with incompatible authentication params' do
+    before do
+      params.merge!(
+        :auth_password => "passw0rd"
+      )
+    end
+    it_raises 'a Puppet::Error', /auth_password and password must not be used together/
+  end
+
+  shared_examples_for 'a neutron server with deprecated authentication params' do
+    before do
+      params.merge!(
+        :auth_user     => "neutron",
+        :auth_password => "passw0rd",
+        :auth_tenant   => "services",
+        :auth_region   => "MyRegion",
+        :identity_uri  => "https://foo.bar:5000/"
+      )
+      params.delete(:password)
+    end
+    it 'configures authentication middleware' do
+      is_expected.to contain_neutron_api_config('filter:authtoken/admin_tenant_name').with_value('services');
+      is_expected.to contain_neutron_api_config('filter:authtoken/admin_user').with_value('neutron');
+      is_expected.to contain_neutron_api_config('filter:authtoken/admin_password').with_value('passw0rd');
+      is_expected.to contain_neutron_api_config('filter:authtoken/admin_password').with_secret( true )
+      is_expected.to contain_neutron_api_config('filter:authtoken/identity_uri').with_value('https://foo.bar:5000/');
+      is_expected.to contain_neutron_config('keystone_authtoken/admin_tenant_name').with_value('services');
+      is_expected.to contain_neutron_config('keystone_authtoken/admin_user').with_value('neutron');
+      is_expected.to contain_neutron_config('keystone_authtoken/admin_password').with_value('passw0rd');
+      is_expected.to contain_neutron_config('keystone_authtoken/admin_password').with_secret( true )
+      is_expected.to contain_neutron_config('keystone_authtoken/identity_uri').with_value('https://foo.bar:5000/');
+      is_expected.to contain_neutron_config('keystone_authtoken/auth_region').with_value('MyRegion');
+      is_expected.not_to contain_neutron_config('keystone_authtoken/tenant_name');
+      is_expected.not_to contain_neutron_config('keystone_authtoken/username');
+      is_expected.not_to contain_neutron_config('keystone_authtoken/password');
+      is_expected.not_to contain_neutron_config('keystone_authtoken/auth_url');
+    end
+  end
+
+  shared_examples_for 'VPNaaS, FWaaS and LBaaS package installation' do
+    before do
+      params.merge!(
+        :ensure_vpnaas_package => true,
+        :ensure_fwaas_package  => true,
+        :ensure_lbaas_package  => true
+      )
+    end
+    it 'should install *aaS packages' do
+      is_expected.to contain_package('neutron-lbaas-agent')
+      is_expected.to contain_package('neutron-fwaas')
+      is_expected.to contain_package('neutron-vpnaas-agent')
     end
-    it_raises 'a Puppet::Error', /auth_password must be set/
   end
 
   shared_examples_for 'a neutron server without database synchronization' do
@@ -232,95 +276,55 @@ describe 'neutron::server' do
     end
   end
 
-  describe "with custom keystone auth_uri" do
+  describe "with custom keystone authentication params" do
     let :facts do
-      default_facts.merge({
-        :osfamily               => 'RedHat',
-        :operatingsystemrelease => '7'
-      })
+      @default_facts.merge(test_facts.merge({
+         :osfamily => 'RedHat',
+         :operatingsystemrelease => '7'
+      }))
     end
     before do
       params.merge!({
-        :auth_uri => 'https://foo.bar:1234/',
+        :auth_uri           => 'https://foo.bar:5000/',
+        :auth_url           => 'https://foo.bar:35357/v3',
+        :keystone_auth_type => 'v3password',
+        :project_domain_id  => 'non_default',
+        :project_name       => 'new_services',
+        :user_domain_id     => 'non_default'
       })
     end
-    it 'configures auth_uri' do
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_uri').with_value("https://foo.bar:1234/");
-      # since only auth_uri is set the deprecated auth parameters should
-      # still get set in case they are still in use
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_host').with_value('localhost');
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_port').with_value('35357');
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_protocol').with_value('http');
-    end
-  end
-
-  describe "with custom keystone identity_uri" do
-    let :facts do
-      default_facts.merge({
-        :osfamily               => 'RedHat',
-        :operatingsystemrelease => '7'
-      })
-    end
-    before do
-      params.merge!({
-        :identity_uri => 'https://foo.bar:1234/',
-      })
-    end
-    it 'configures identity_uri' do
-      is_expected.to contain_neutron_config('keystone_authtoken/identity_uri').with_value("https://foo.bar:1234/");
-      # since only auth_uri is set the deprecated auth parameters should
-      # still get set in case they are still in use
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_host').with_value('localhost');
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_port').with_value('35357');
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_protocol').with_value('http');
-    end
-  end
-
-  describe "with custom keystone identity_uri and auth_uri" do
-    let :facts do
-      default_facts.merge({
-        :osfamily => 'RedHat',
-        :operatingsystemrelease => '7'
-      })
-    end
-    before do
-      params.merge!({
-        :identity_uri => 'https://foo.bar:35357/',
-        :auth_uri => 'https://foo.bar:5000/v2.0/',
-      })
-    end
-    it 'configures identity_uri and auth_uri but deprecates old auth settings' do
-      is_expected.to contain_neutron_config('keystone_authtoken/identity_uri').with_value("https://foo.bar:35357/");
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_uri').with_value("https://foo.bar:5000/v2.0/");
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_admin_prefix').with(:ensure => 'absent')
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_port').with(:ensure => 'absent')
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_protocol').with(:ensure => 'absent')
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_host').with(:ensure => 'absent')
+    it 'configures keystone authentication params' do
+      is_expected.to contain_neutron_config('keystone_authtoken/auth_uri').with_value("https://foo.bar:5000/");
+      is_expected.to contain_neutron_config('keystone_authtoken/auth_url').with_value("https://foo.bar:35357/v3");
+      is_expected.to contain_neutron_config('keystone_authtoken/project_domain_id').with_value("non_default");
+      is_expected.to contain_neutron_config('keystone_authtoken/project_name').with_value("new_services");
+      is_expected.to contain_neutron_config('keystone_authtoken/user_domain_id').with_value("non_default");
     end
   end
 
   describe "with custom auth region" do
     let :facts do
-      default_facts.merge({
-        :osfamily               => 'RedHat',
-        :operatingsystemrelease => '7'
-      })
+      @default_facts.merge(test_facts.merge({
+         :osfamily               => 'RedHat',
+         :operatingsystemrelease => '7'
+      }))
     end
     before do
       params.merge!({
-        :auth_region => 'MyRegion',
+        :region_name => 'MyRegion',
       })
     end
-    it 'configures auth_region' do
-      is_expected.to contain_neutron_config('keystone_authtoken/auth_region').with_value('MyRegion');
+    it 'configures region_name' do
+      is_expected.to contain_neutron_config('keystone_authtoken/region_name').with_value('MyRegion');
     end
   end
 
   context 'on Debian platforms' do
     let :facts do
-      default_facts.merge(
-        { :osfamily => 'Debian',
-          :processorcount => '2' })
+      @default_facts.merge(test_facts.merge({
+         :osfamily => 'Debian',
+         :processorcount => '2'
+      }))
     end
 
     let :platform_params do
@@ -330,18 +334,18 @@ describe 'neutron::server' do
 
     it_configures 'a neutron server'
     it_configures 'a neutron server with broken authentication'
-    it_configures 'a neutron server with auth_admin_prefix set'
-    it_configures 'a neutron server with some incorrect auth_admin_prefix set'
+    it_configures 'a neutron server with incompatible authentication params'
+    it_configures 'a neutron server with deprecated authentication params'
     it_configures 'a neutron server without database synchronization'
   end
 
   context 'on RedHat platforms' do
     let :facts do
-      default_facts.merge(
-        { :osfamily               => 'RedHat',
+      @default_facts.merge(test_facts.merge({
+          :osfamily               => 'RedHat',
           :operatingsystemrelease => '7',
           :processorcount         => '2'
-      })
+      }))
     end
 
     let :platform_params do
@@ -350,8 +354,8 @@ describe 'neutron::server' do
 
     it_configures 'a neutron server'
     it_configures 'a neutron server with broken authentication'
-    it_configures 'a neutron server with auth_admin_prefix set'
-    it_configures 'a neutron server with some incorrect auth_admin_prefix set'
+    it_configures 'a neutron server with incompatible authentication params'
+    it_configures 'a neutron server with deprecated authentication params'
     it_configures 'a neutron server without database synchronization'
   end
 end
